@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only  */
-/* Copyright (c) 2021 - 2023 Gavin Henry <ghenry@sentrypeer.org> */
+/* Copyright (c) 2021 - 2025 Gavin Henry <ghenry@sentrypeer.org> */
 /*
    _____            _              _____
   / ____|          | |            |  __ \
@@ -32,18 +32,21 @@
 #include <time.h>
 #include <syslog.h>
 #include <assert.h>
+#include <errno.h>
 
 #include "conf.h"
 #include "sip_daemon.h"
 #include "sip_message_event.h"
 #include "sip_parser.h"
-#include "database.h"
-#include "json_logger.h"
 
 #if HAVE_OPENDHT_C != 0
 #include "peer_to_peer_dht.h"
 #endif // HAVE_OPENDHT_C
 
+#if HAVE_RUST != 0
+#include "sentrypeer_rust.h"
+#endif // HAVE_RUST
+
 #define PACKET_BUFFER_SIZE 1024
 
 void *sip_daemon_thread_start(void *arg)
@@ -73,6 +76,11 @@ int sip_daemon_run(sentrypeer_config *config)
 	if (pthread_setname_np(sip_daemon_thread, sip_daemon_thread_name) !=
 	    EXIT_SUCCESS) {
 		fprintf(stderr, "Failed to set SIP daemon thread name.\n");
+		// Error is?
+		fprintf(stderr, "Error is: %d\n", errno);
+		// Error description?
+		fprintf(stderr, "Error description is: %s\n", strerror(errno));
+
 		return EXIT_FAILURE;
 	}
 #endif
@@ -81,21 +89,47 @@ int sip_daemon_run(sentrypeer_config *config)
 	return EXIT_SUCCESS;
 }
 
+#if HAVE_RUST != 0
+int shutdown_sip_server(sentrypeer_config const *config)
+{
+	if (shutdown_sip(config) != EXIT_SUCCESS) {
+		fprintf(stderr, "Failed to shutdown TLS listener.\n");
+		return EXIT_FAILURE;
+	}
+	return EXIT_SUCCESS;
+}
+#endif // HAVE_RUST
+
 int sip_daemon_stop(sentrypeer_config const *config)
 {
-	if (config->debug_mode || config->verbose_mode) {
-		fprintf(stderr, "Stopping sip daemon...\n");
+    // default if no Rust or set via config file/CLI/ENV
+	if (config->new_mode == false) {
+		if (config->debug_mode || config->verbose_mode) {
+			fprintf(stderr, "Stopping sip daemon...\n");
+		}
+
+		if (pthread_cancel(config->sip_daemon_thread) != EXIT_SUCCESS) {
+			fprintf(stderr,
+				"Failed to cancel SIP daemon thread.\n");
+			return EXIT_FAILURE;
+		}
+
+		if (pthread_join(config->sip_daemon_thread, NULL) !=
+		    EXIT_SUCCESS) {
+			fprintf(stderr, "Failed to join SIP daemon thread.\n");
+			return EXIT_FAILURE;
+		}
 	}
 
-	if (pthread_cancel(config->sip_daemon_thread) != EXIT_SUCCESS) {
-		fprintf(stderr, "Failed to cancel SIP daemon thread.\n");
-		return EXIT_FAILURE;
-	}
-
-	if (pthread_join(config->sip_daemon_thread, NULL) != EXIT_SUCCESS) {
-		fprintf(stderr, "Failed to join SIP daemon thread.\n");
-		return EXIT_FAILURE;
+	// Shutdown our Rust listeners
+#if HAVE_RUST != 0
+	if (config->new_mode == true) {
+		if (shutdown_sip_server(config) != EXIT_SUCCESS) {
+			fprintf(stderr, "Failed to shutdown TLS listener.\n");
+			return EXIT_FAILURE;
+		}
 	}
+#endif // HAVE_RUST
 
 	return EXIT_SUCCESS;
 }
@@ -158,19 +192,19 @@ int sip_send_reply(sentrypeer_config const *config,
 	// Actors don't seem to care we're always replying
 	// with 200 OK/non-compliant SIP :-)
 	char SIP_200_OK[] =
-		"SIP/2.0 200 OK\n"
-		"Via: SIP/2.0/UDP 127.0.0.1:56940\n"
-		"Call-ID: 1179563087@127.0.0.1\n"
-		"From: <sip:sipsak@127.0.0.1>;tag=464eb44f\n"
-		"To: <sip:asterisk@127.0.0.1>;tag=z9hG4bK.1c882828\n"
-		"CSeq: 1 OPTIONS\n"
-		"Accept: application/sdp, application/dialog-info+xml, application/simple-message-summary, application/xpidf+xml, application/cpim-pidf+xml, application/pidf+xml, application/pidf+xml, application/dialog-info+xml, application/simple-message-summary, message/sipfrag;version=2.0\n"
-		"Allow: OPTIONS, SUBSCRIBE, NOTIFY, PUBLISH, INVITE, ACK, BYE, CANCEL, UPDATE, PRACK, REGISTER, REFER, MESSAGE\n"
-		"Supported: 100rel, timer, replaces, norefersub\n"
-		"Accept-Encoding: text/plain\n"
-		"Accept-Language: en\n"
-		"Server: FPBX-16.0.33(18.13.0)\n"
-		"Content-Length:  0";
+		"SIP/2.0 200 OK\r\n"
+		"Via: SIP/2.0/UDP 127.0.0.1:56940\r\n"
+		"Call-ID: 1179563087@127.0.0.1\r\n"
+		"From: <sip:sipsak@127.0.0.1>;tag=464eb44f\r\n"
+		"To: <sip:asterisk@127.0.0.1>;tag=z9hG4bK.1c882828\r\n"
+		"CSeq: 1 OPTIONS\r\n"
+		"Accept: application/sdp, application/dialog-info+xml, application/simple-message-summary, application/xpidf+xml, application/cpim-pidf+xml, application/pidf+xml, application/pidf+xml, application/dialog-info+xml, application/simple-message-summary, message/sipfrag;version=2.0\r\n"
+		"Allow: OPTIONS, SUBSCRIBE, NOTIFY, PUBLISH, INVITE, ACK, BYE, CANCEL, UPDATE, PRACK, REGISTER, REFER, MESSAGE\r\n"
+		"Supported: 100rel, timer, replaces, norefersub\r\n"
+		"Accept-Encoding: text/plain\r\n"
+		"Accept-Language: en\r\n"
+		"Server: FPBX-16.0.33(18.13.0)\r\n"
+		"Content-Length:  0\r\n";
 
 	long bytes_sent =
 		sendto(sip_event->socket, SIP_200_OK, sizeof(SIP_200_OK), 0,
@@ -458,17 +492,6 @@ int sip_daemon_init(sentrypeer_config *config)
 							tcp_client_ip_address_buffer);
 					}
 
-#ifndef SO_ORIGINAL_DST
-#define SO_ORIGINAL_DST 80
-#endif
-
-// Only on Linux - https://man7.org/linux/man-pages/man7/ip.7.html
-// Using the SOL_IP socket options level isn't portable; BSD-based
-// stacks use the IPPROTO_IP level.
-#ifndef SOL_IP
-#define SOL_IP IPPROTO_IP
-#endif
-
 					struct sockaddr_in destination_address;
 					socklen_t destination_address_len =
 						sizeof(destination_address);
@@ -476,9 +499,10 @@ int sip_daemon_init(sentrypeer_config *config)
 					       destination_address_len);
 					destination_address.sin_family =
 						AF_INET;
-					if (getsockopt(
-						    i, SOL_IP, SO_ORIGINAL_DST,
-						    &destination_address,
+					if (getsockname(
+						    i,
+						    (struct sockaddr
+							     *)&destination_address,
 						    &destination_address_len) ==
 					    EXIT_SUCCESS) {
 						dest_ip_address_buffer =
@@ -495,7 +519,7 @@ int sip_daemon_init(sentrypeer_config *config)
 										.sin_addr));
 						}
 					}
-
+					assert(dest_ip_address_buffer);
 					socklen_t tcp_client_len = sizeof(i);
 
 					char transport_type[] = "TCP";
