@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only  */
-/* Copyright (c) 2021 - 2023 Gavin Henry <ghenry@sentrypeer.org> */
+/* Copyright (c) 2021 - 2025 Gavin Henry <ghenry@sentrypeer.org> */
 /* 
    _____            _              _____
   / ____|          | |            |  __ \
@@ -41,7 +41,7 @@ sip_message_event *sip_message_event_new(char *packet, size_t packet_len,
 					 SOCKET socket, char *transport_type,
 					 struct sockaddr *client_ip_addr,
 					 char *client_ip_addr_str,
-					 size_t client_addr_len,
+					 size_t client_ip_addr_len,
 					 char *dest_ip_addr_str);
 
 //  Destructors
